"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
from django.core.management.base import BaseCommand

from artd_location.data.countries import COUNTRIES
from artd_location.models import Country


class Command(BaseCommand):
    help = "Create countries"

    def handle(self, *args, **kwargs):
        for country in COUNTRIES:
            if Country.objects.filter(id=country[0]).count() == 0:
                Country.objects.create(
                    id=country[0],
                    spanish_name=country[1],
                    english_name=country[2],
                    nom=country[3],
                    iso2=country[4],
                    iso3=country[5],
                    phone_code=country[6],
                )
                print(f"{country[1]} was created")
            else:
                country_obj = Country.objects.get(
                    id=country[0],
                )
                country_obj.spanish_name = country[1]
                country_obj.english_name = country[2]
                country_obj.nom = country[3]
                country_obj.iso2 = country[4]
                country_obj.iso3 = country[5]
                country_obj.phone_code = country[6]
                country_obj.save()
                print(f"{country[1]} was updated")



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
COUNTRIES = [
    [
        1,
        "Afganistán",
        "Afghanistan",
        "Afghanistan",
        "AF",
        "AFG",
        "93",
    ],
    [
        2,
        "Albania",
        "Albania",
        "Albanie",
        "AL",
        "ALB",
        "355",
    ],
    [
        3,
        "Alemania",
        "Germany",
        "Allemagne",
        "DE",
        "DEU",
        "49",
    ],
    [
        4,
        "Algeria",
        "Algeria",
        "Algérie",
        "DZ",
        "DZA",
        "213",
    ],
    [
        5,
        "Andorra",
        "Andorra",
        "Andorra",
        "AD",
        "AND",
        "376",
    ],
    [
        6,
        "Angola",
        "Angola",
        "Angola",
        "AO",
        "AGO",
        "244",
    ],
    [
        7,
        "Anguila",
        "Anguilla",
        "Anguilla",
        "AI",
        "AIA",
        "1 264",
    ],
    [
        8,
        "Antártida",
        "Antarctica",
        "LAntarctique",
        "AQ",
        "ATA",
        "672",
    ],
    [
        9,
        "Antigua y Barbuda",
        "Antigua and Barbuda",
        "Antigua et Barbuda",
        "AG",
        "ATG",
        "1 268",
    ],
    [
        10,
        "Antillas Neerlandesas",
        "Netherlands Antilles",
        "Antilles Néerlandaises",
        "AN",
        "ANT",
        "599",
    ],
    [
        11,
        "Arabia Saudita",
        "Saudi Arabia",
        "Arabie Saoudite",
        "SA",
        "SAU",
        "966",
    ],
    [
        12,
        "Argentina",
        "Argentina",
        "Argentine",
        "AR",
        "ARG",
        "54",
    ],
    [
        13,
        "Armenia",
        "Armenia",
        "LArménie",
        "AM",
        "ARM",
        "374",
    ],
    [
        14,
        "Aruba",
        "Aruba",
        "Aruba",
        "AW",
        "ABW",
        "297",
    ],
    [
        15,
        "Australia",
        "Australia",
        "Australie",
        "AU",
        "AUS",
        "61",
    ],
    [
        16,
        "Austria",
        "Austria",
        "Autriche",
        "AT",
        "AUT",
        "43",
    ],
    [
        17,
        "Azerbayán",
        "Azerbaijan",
        "LAzerbaïdjan",
        "AZ",
        "AZE",
        "994",
    ],
    [
        18,
        "Bélgica",
        "Belgium",
        "Belgique",
        "BE",
        "BEL",
        "32",
    ],
    [
        19,
        "Bahamas",
        "Bahamas",
        "Bahamas",
        "BS",
        "BHS",
        "1 242",
    ],
    [
        20,
        "Bahrein",
        "Bahrain",
        "Bahreïn",
        "BH",
        "BHR",
        "973",
    ],
    [
        21,
        "Bangladesh",
        "Bangladesh",
        "Bangladesh",
        "BD",
        "BGD",
        "880",
    ],
    [
        22,
        "Barbados",
        "Barbados",
        "Barbade",
        "BB",
        "BRB",
        "1 246",
    ],
    [
        23,
        "Belice",
        "Belize",
        "Belize",
        "BZ",
        "BLZ",
        "501",
    ],
    [
        24,
        "Benín",
        "Benin",
        "Bénin",
        "BJ",
        "BEN",
        "229",
    ],
    [
        25,
        "Bhután",
        "Bhutan",
        "Le Bhoutan",
        "BT",
        "BTN",
        "975",
    ],
    [
        26,
        "Bielorrusia",
        "Belarus",
        "Biélorussie",
        "BY",
        "BLR",
        "375",
    ],
    [
        27,
        "Birmania",
        "Myanmar",
        "Myanmar",
        "MM",
        "MMR",
        "95",
    ],
    [
        28,
        "Bolivia",
        "Bolivia",
        "Bolivie",
        "BO",
        "BOL",
        "591",
    ],
    [
        29,
        "Bosnia y Herzegovina",
        "Bosnia and Herzegovina",
        "Bosnie-Herzégovine",
        "BA",
        "BIH",
        "387",
    ],
    [
        30,
        "Botsuana",
        "Botswana",
        "Botswana",
        "BW",
        "BWA",
        "267",
    ],
    [
        31,
        "Brasil",
        "Brazil",
        "Brésil",
        "BR",
        "BRA",
        "55",
    ],
    [
        32,
        "Brunéi",
        "Brunei",
        "Brunei",
        "BN",
        "BRN",
        "673",
    ],
    [
        33,
        "Bulgaria",
        "Bulgaria",
        "Bulgarie",
        "BG",
        "BGR",
        "359",
    ],
    [
        34,
        "Burkina Faso",
        "Burkina Faso",
        "Burkina Faso",
        "BF",
        "BFA",
        "226",
    ],
    [
        35,
        "Burundi",
        "Burundi",
        "Burundi",
        "BI",
        "BDI",
        "257",
    ],
    [
        36,
        "Cabo Verde",
        "Cape Verde",
        "Cap-Vert",
        "CV",
        "CPV",
        "238",
    ],
    [
        37,
        "Camboya",
        "Cambodia",
        "Cambodge",
        "KH",
        "KHM",
        "855",
    ],
    [
        38,
        "Camerún",
        "Cameroon",
        "Cameroun",
        "CM",
        "CMR",
        "237",
    ],
    [
        39,
        "Canadá",
        "Canada",
        "Canada",
        "CA",
        "CAN",
        "1",
    ],
    [
        40,
        "Chad",
        "Chad",
        "Tchad",
        "TD",
        "TCD",
        "235",
    ],
    [
        41,
        "Chile",
        "Chile",
        "Chili",
        "CL",
        "CHL",
        "56",
    ],
    [
        42,
        "China",
        "China",
        "Chine",
        "CN",
        "CHN",
        "86",
    ],
    [
        43,
        "Chipre",
        "Cyprus",
        "Chypre",
        "CY",
        "CYP",
        "357",
    ],
    [
        44,
        "Ciudad del Vaticano",
        "Vatican City State",
        "Cité du Vatican",
        "VA",
        "VAT",
        "39",
    ],
    [
        45,
        "Colombia",
        "Colombia",
        "Colombie",
        "CO",
        "COL",
        "57",
    ],
    [
        46,
        "Comoras",
        "Comoros",
        "Comores",
        "KM",
        "COM",
        "269",
    ],
    [
        47,
        "Congo",
        "Congo",
        "Congo",
        "CG",
        "COG",
        "242",
    ],
    [
        48,
        "Congo",
        "Congo",
        "Congo",
        "CD",
        "COD",
        "243",
    ],
    [
        49,
        "Corea del Norte",
        "North Korea",
        "Corée du Nord",
        "KP",
        "PRK",
        "850",
    ],
    [
        50,
        "Corea del Sur",
        "South Korea",
        "Corée du Sud",
        "KR",
        "KOR",
        "82",
    ],
    [
        51,
        "Costa de Marfil",
        "Ivory Coast",
        "Côte-dIvoire",
        "CI",
        "CIV",
        "225",
    ],
    [
        52,
        "Costa Rica",
        "Costa Rica",
        "Costa Rica",
        "CR",
        "CRI",
        "506",
    ],
    [
        53,
        "Croacia",
        "Croatia",
        "Croatie",
        "HR",
        "HRV",
        "385",
    ],
    [
        54,
        "Cuba",
        "Cuba",
        "Cuba",
        "CU",
        "CUB",
        "53",
    ],
    [
        55,
        "Dinamarca",
        "Denmark",
        "Danemark",
        "DK",
        "DNK",
        "45",
    ],
    [
        56,
        "Dominica",
        "Dominica",
        "Dominique",
        "DM",
        "DMA",
        "1 767",
    ],
    [
        57,
        "Ecuador",
        "Ecuador",
        "Equateur",
        "EC",
        "ECU",
        "593",
    ],
    [
        58,
        "Egipto",
        "Egypt",
        "Egypte",
        "EG",
        "EGY",
        "20",
    ],
    [
        59,
        "El Salvador",
        "El Salvador",
        "El Salvador",
        "SV",
        "SLV",
        "503",
    ],
    [
        60,
        "Emiratos Árabes Unidos",
        "United Arab Emirates",
        "Emirats Arabes Unis",
        "AE",
        "ARE",
        "971",
    ],
    [
        61,
        "Eritrea",
        "Eritrea",
        "Erythrée",
        "ER",
        "ERI",
        "291",
    ],
    [
        62,
        "Eslovaquia",
        "Slovakia",
        "Slovaquie",
        "SK",
        "SVK",
        "421",
    ],
    [
        63,
        "Eslovenia",
        "Slovenia",
        "Slovénie",
        "SI",
        "SVN",
        "386",
    ],
    [
        64,
        "España",
        "Spain",
        "Espagne",
        "ES",
        "ESP",
        "34",
    ],
    [
        65,
        "Estados Unidos de América",
        "United States of America",
        "États-Unis dAmérique",
        "US",
        "USA",
        "1",
    ],
    [
        66,
        "Estonia",
        "Estonia",
        "LEstonie",
        "EE",
        "EST",
        "372",
    ],
    [
        67,
        "Etiopía",
        "Ethiopia",
        "Ethiopie",
        "ET",
        "ETH",
        "251",
    ],
    [
        68,
        "Filipinas",
        "Philippines",
        "Philippines",
        "PH",
        "PHL",
        "63",
    ],
    [
        69,
        "Finlandia",
        "Finland",
        "Finlande",
        "FI",
        "FIN",
        "358",
    ],
    [
        70,
        "Fiyi",
        "Fiji",
        "Fidji",
        "FJ",
        "FJI",
        "679",
    ],
    [
        71,
        "Francia",
        "France",
        "France",
        "FR",
        "FRA",
        "33",
    ],
    [
        72,
        "Gabón",
        "Gabon",
        "Gabon",
        "GA",
        "GAB",
        "241",
    ],
    [
        73,
        "Gambia",
        "Gambia",
        "Gambie",
        "GM",
        "GMB",
        "220",
    ],
    [
        74,
        "Georgia",
        "Georgia",
        "Géorgie",
        "GE",
        "GEO",
        "995",
    ],
    [
        75,
        "Ghana",
        "Ghana",
        "Ghana",
        "GH",
        "GHA",
        "233",
    ],
    [
        76,
        "Gibraltar",
        "Gibraltar",
        "Gibraltar",
        "GI",
        "GIB",
        "350",
    ],
    [
        77,
        "Granada",
        "Grenada",
        "Grenade",
        "GD",
        "GRD",
        "1 473",
    ],
    [
        78,
        "Grecia",
        "Greece",
        "Grèce",
        "GR",
        "GRC",
        "30",
    ],
    [
        79,
        "Groenlandia",
        "Greenland",
        "Groenland",
        "GL",
        "GRL",
        "299",
    ],
    [
        80,
        "Guadalupe",
        "Guadeloupe",
        "Guadeloupe",
        "GP",
        "GLP",
        "",
    ],
    [
        81,
        "Guam",
        "Guam",
        "Guam",
        "GU",
        "GUM",
        "1 671",
    ],
    [
        82,
        "Guatemala",
        "Guatemala",
        "Guatemala",
        "GT",
        "GTM",
        "502",
    ],
    [
        83,
        "Guayana Francesa",
        "French Guiana",
        "Guyane française",
        "GF",
        "GUF",
        "",
    ],
    [
        84,
        "Guernsey",
        "Guernsey",
        "Guernesey",
        "GG",
        "GGY",
        "",
    ],
    [
        85,
        "Guinea",
        "Guinea",
        "Guinée",
        "GN",
        "GIN",
        "224",
    ],
    [
        86,
        "Guinea Ecuatorial",
        "Equatorial Guinea",
        "Guinée Equatoriale",
        "GQ",
        "GNQ",
        "240",
    ],
    [
        87,
        "Guinea-Bissau",
        "Guinea-Bissau",
        "Guinée-Bissau",
        "GW",
        "GNB",
        "245",
    ],
    [
        88,
        "Guyana",
        "Guyana",
        "Guyane",
        "GY",
        "GUY",
        "592",
    ],
    [
        89,
        "Haití",
        "Haiti",
        "Haïti",
        "HT",
        "HTI",
        "509",
    ],
    [
        90,
        "Honduras",
        "Honduras",
        "Honduras",
        "HN",
        "HND",
        "504",
    ],
    [
        91,
        "Hong kong",
        "Hong Kong",
        "Hong Kong",
        "HK",
        "HKG",
        "852",
    ],
    [
        92,
        "Hungría",
        "Hungary",
        "Hongrie",
        "HU",
        "HUN",
        "36",
    ],
    [
        93,
        "India",
        "India",
        "Inde",
        "IN",
        "IND",
        "91",
    ],
    [
        94,
        "Indonesia",
        "Indonesia",
        "Indonésie",
        "ID",
        "IDN",
        "62",
    ],
    [
        95,
        "Irán",
        "Iran",
        "Iran",
        "IR",
        "IRN",
        "98",
    ],
    [
        96,
        "Irak",
        "Iraq",
        "Irak",
        "IQ",
        "IRQ",
        "964",
    ],
    [
        97,
        "Irlanda",
        "Ireland",
        "Irlande",
        "IE",
        "IRL",
        "353",
    ],
    [
        98,
        "Isla Bouvet",
        "Bouvet Island",
        "Bouvet Island",
        "BV",
        "BVT",
        "",
    ],
    [
        99,
        "Isla de Man",
        "Isle of Man",
        "Ile de Man",
        "IM",
        "IMN",
        "44",
    ],
    [
        100,
        "Isla de Navidad",
        "Christmas Island",
        "Christmas Island",
        "CX",
        "CXR",
        "61",
    ],
    [
        101,
        "Isla Norfolk",
        "Norfolk Island",
        "Île de Norfolk",
        "NF",
        "NFK",
        "",
    ],
    [
        102,
        "Islandia",
        "Iceland",
        "Islande",
        "IS",
        "ISL",
        "354",
    ],
    [
        103,
        "Islas Bermudas",
        "Bermuda Islands",
        "Bermudes",
        "BM",
        "BMU",
        "1 441",
    ],
    [
        104,
        "Islas Caimán",
        "Cayman Islands",
        "Iles Caïmans",
        "KY",
        "CYM",
        "1 345",
    ],
    [
        105,
        "Islas Cocos (Keeling)",
        "Cocos (Keeling) Islands",
        "Cocos (Keeling",
        "CC",
        "CCK",
        "61",
    ],
    [
        106,
        "Islas Cook",
        "Cook Islands",
        "Iles Cook",
        "CK",
        "COK",
        "682",
    ],
    [
        107,
        "Islas de Åland",
        "Åland Islands",
        "Îles Åland",
        "AX",
        "ALA",
        "",
    ],
    [
        108,
        "Islas Feroe",
        "Faroe Islands",
        "Iles Féro",
        "FO",
        "FRO",
        "298",
    ],
    [
        109,
        "Islas Georgias del Sur y Sandwich del Sur",
        "South Georgia and the South Sandwich Islands",
        "Géorgie du Sud et les Îles Sandwich du Sud",
        "GS",
        "SGS",
        "",
    ],
    [
        110,
        "Islas Heard y McDonald",
        "Heard Island and McDonald Islands",
        "Les îles Heard et McDonald",
        "HM",
        "HMD",
        "",
    ],
    [
        111,
        "Islas Maldivas",
        "Maldives",
        "Maldives",
        "MV",
        "MDV",
        "960",
    ],
    [
        112,
        "Islas Malvinas",
        "Falkland Islands (Malvinas)",
        "Iles Falkland (Malvinas",
        "FK",
        "FLK",
        "500",
    ],
    [
        113,
        "Islas Marianas del Norte",
        "Northern Mariana Islands",
        "Iles Mariannes du Nord",
        "MP",
        "MNP",
        "1 670",
    ],
    [
        114,
        "Islas Marshall",
        "Marshall Islands",
        "Iles Marshall",
        "MH",
        "MHL",
        "692",
    ],
    [
        115,
        "Islas Pitcairn",
        "Pitcairn Islands",
        "Iles Pitcairn",
        "PN",
        "PCN",
        "870",
    ],
    [
        116,
        "Islas Salomón",
        "Solomon Islands",
        "Iles Salomon",
        "SB",
        "SLB",
        "677",
    ],
    [
        117,
        "Islas Turcas y Caicos",
        "Turks and Caicos Islands",
        "Iles Turques et Caïques",
        "TC",
        "TCA",
        "1 649",
    ],
    [
        118,
        "Islas Ultramarinas Menores de Estados Unidos",
        "United States Minor Outlying Islands",
        "États-Unis Îles mineures éloignées",
        "UM",
        "UMI",
        "",
    ],
    [
        119,
        "Islas Vírgenes Británicas",
        "Virgin Islands",
        "Iles Vierges",
        "VG",
        "VG",
        "1 284",
    ],
    [
        120,
        "Islas Vírgenes de los Estados Unidos",
        "United States Virgin Islands",
        "Îles Vierges américaines",
        "VI",
        "VIR",
        "1 340",
    ],
    [
        121,
        "Israel",
        "Israel",
        "Israël",
        "IL",
        "ISR",
        "972",
    ],
    [
        122,
        "Italia",
        "Italy",
        "Italie",
        "IT",
        "ITA",
        "39",
    ],
    [
        123,
        "Jamaica",
        "Jamaica",
        "Jamaïque",
        "JM",
        "JAM",
        "1 876",
    ],
    [
        124,
        "Japón",
        "Japan",
        "Japon",
        "JP",
        "JPN",
        "81",
    ],
    [
        125,
        "Jersey",
        "Jersey",
        "Maillot",
        "JE",
        "JEY",
        "",
    ],
    [
        126,
        "Jordania",
        "Jordan",
        "Jordan",
        "JO",
        "JOR",
        "962",
    ],
    [
        127,
        "Kazajistán",
        "Kazakhstan",
        "Le Kazakhstan",
        "KZ",
        "KAZ",
        "7",
    ],
    [
        128,
        "Kenia",
        "Kenya",
        "Kenya",
        "KE",
        "KEN",
        "254",
    ],
    [
        129,
        "Kirgizstán",
        "Kyrgyzstan",
        "Kirghizstan",
        "KG",
        "KGZ",
        "996",
    ],
    [
        130,
        "Kiribati",
        "Kiribati",
        "Kiribati",
        "KI",
        "KIR",
        "686",
    ],
    [
        131,
        "Kuwait",
        "Kuwait",
        "Koweït",
        "KW",
        "KWT",
        "965",
    ],
    [
        132,
        "Líbano",
        "Lebanon",
        "Liban",
        "LB",
        "LBN",
        "961",
    ],
    [
        133,
        "Laos",
        "Laos",
        "Laos",
        "LA",
        "LAO",
        "856",
    ],
    [
        134,
        "Lesoto",
        "Lesotho",
        "Lesotho",
        "LS",
        "LSO",
        "266",
    ],
    [
        135,
        "Letonia",
        "Latvia",
        "La Lettonie",
        "LV",
        "LVA",
        "371",
    ],
    [
        136,
        "Liberia",
        "Liberia",
        "Liberia",
        "LR",
        "LBR",
        "231",
    ],
    [
        137,
        "Libia",
        "Libya",
        "Libye",
        "LY",
        "LBY",
        "218",
    ],
    [
        138,
        "Liechtenstein",
        "Liechtenstein",
        "Liechtenstein",
        "LI",
        "LIE",
        "423",
    ],
    [
        139,
        "Lituania",
        "Lithuania",
        "La Lituanie",
        "LT",
        "LTU",
        "370",
    ],
    [
        140,
        "Luxemburgo",
        "Luxembourg",
        "Luxembourg",
        "LU",
        "LUX",
        "352",
    ],
    [
        141,
        "México",
        "Mexico",
        "Mexique",
        "MX",
        "MEX",
        "52",
    ],
    [
        142,
        "Mónaco",
        "Monaco",
        "Monaco",
        "MC",
        "MCO",
        "377",
    ],
    [
        143,
        "Macao",
        "Macao",
        "Macao",
        "MO",
        "MAC",
        "853",
    ],
    [
        144,
        "Macedônia",
        "Macedonia",
        "Macédoine",
        "MK",
        "MKD",
        "389",
    ],
    [
        145,
        "Madagascar",
        "Madagascar",
        "Madagascar",
        "MG",
        "MDG",
        "261",
    ],
    [
        146,
        "Malasia",
        "Malaysia",
        "Malaisie",
        "MY",
        "MYS",
        "60",
    ],
    [
        147,
        "Malawi",
        "Malawi",
        "Malawi",
        "MW",
        "MWI",
        "265",
    ],
    [
        148,
        "Mali",
        "Mali",
        "Mali",
        "ML",
        "MLI",
        "223",
    ],
    [
        149,
        "Malta",
        "Malta",
        "Malte",
        "MT",
        "MLT",
        "356",
    ],
    [
        150,
        "Marruecos",
        "Morocco",
        "Maroc",
        "MA",
        "MAR",
        "212",
    ],
    [
        151,
        "Martinica",
        "Martinique",
        "Martinique",
        "MQ",
        "MTQ",
        "",
    ],
    [
        152,
        "Mauricio",
        "Mauritius",
        "Iles Maurice",
        "MU",
        "MUS",
        "230",
    ],
    [
        153,
        "Mauritania",
        "Mauritania",
        "Mauritanie",
        "MR",
        "MRT",
        "222",
    ],
    [
        154,
        "Mayotte",
        "Mayotte",
        "Mayotte",
        "YT",
        "MYT",
        "262",
    ],
    [
        155,
        "Micronesia",
        "Estados Federados de",
        "Federados Estados de",
        "FM",
        "FSM",
        "691",
    ],
    [
        156,
        "Moldavia",
        "Moldova",
        "Moldavie",
        "MD",
        "MDA",
        "373",
    ],
    [
        157,
        "Mongolia",
        "Mongolia",
        "Mongolie",
        "MN",
        "MNG",
        "976",
    ],
    [
        158,
        "Montenegro",
        "Montenegro",
        "Monténégro",
        "ME",
        "MNE",
        "382",
    ],
    [
        159,
        "Montserrat",
        "Montserrat",
        "Montserrat",
        "MS",
        "MSR",
        "1 664",
    ],
    [
        160,
        "Mozambique",
        "Mozambique",
        "Mozambique",
        "MZ",
        "MOZ",
        "258",
    ],
    [
        161,
        "Namibia",
        "Namibia",
        "Namibie",
        "NA",
        "NAM",
        "264",
    ],
    [
        162,
        "Nauru",
        "Nauru",
        "Nauru",
        "NR",
        "NRU",
        "674",
    ],
    [
        163,
        "Nepal",
        "Nepal",
        "Népal",
        "NP",
        "NPL",
        "977",
    ],
    [
        164,
        "Nicaragua",
        "Nicaragua",
        "Nicaragua",
        "NI",
        "NIC",
        "505",
    ],
    [
        165,
        "Niger",
        "Niger",
        "Niger",
        "NE",
        "NER",
        "227",
    ],
    [
        166,
        "Nigeria",
        "Nigeria",
        "Nigeria",
        "NG",
        "NGA",
        "234",
    ],
    [
        167,
        "Niue",
        "Niue",
        "Niou",
        "NU",
        "NIU",
        "683",
    ],
    [
        168,
        "Noruega",
        "Norway",
        "Norvège",
        "NO",
        "NOR",
        "47",
    ],
    [
        169,
        "Nueva Caledonia",
        "New Caledonia",
        "Nouvelle-Calédonie",
        "NC",
        "NCL",
        "687",
    ],
    [
        170,
        "Nueva Zelanda",
        "New Zealand",
        "Nouvelle-Zélande",
        "NZ",
        "NZL",
        "64",
    ],
    [
        171,
        "Omán",
        "Oman",
        "Oman",
        "OM",
        "OMN",
        "968",
    ],
    [
        172,
        "Países Bajos",
        "Netherlands",
        "Pays-Bas",
        "NL",
        "NLD",
        "31",
    ],
    [
        173,
        "Pakistán",
        "Pakistan",
        "Pakistan",
        "PK",
        "PAK",
        "92",
    ],
    [
        174,
        "Palau",
        "Palau",
        "Palau",
        "PW",
        "PLW",
        "680",
    ],
    [
        175,
        "Palestina",
        "Palestine",
        "La Palestine",
        "PS",
        "PSE",
        "",
    ],
    [
        176,
        "Panamá",
        "Panama",
        "Panama",
        "PA",
        "PAN",
        "507",
    ],
    [
        177,
        "Papúa Nueva Guinea",
        "Papua New Guinea",
        "Papouasie-Nouvelle-Guinée",
        "PG",
        "PNG",
        "675",
    ],
    [
        178,
        "Paraguay",
        "Paraguay",
        "Paraguay",
        "PY",
        "PRY",
        "595",
    ],
    [
        179,
        "Perú",
        "Peru",
        "Pérou",
        "PE",
        "PER",
        "51",
    ],
    [
        180,
        "Polinesia Francesa",
        "French Polynesia",
        "Polynésie française",
        "PF",
        "PYF",
        "689",
    ],
    [
        181,
        "Polonia",
        "Poland",
        "Pologne",
        "PL",
        "POL",
        "48",
    ],
    [
        182,
        "Portugal",
        "Portugal",
        "Portugal",
        "PT",
        "PRT",
        "351",
    ],
    [
        183,
        "Puerto Rico",
        "Puerto Rico",
        "Porto Rico",
        "PR",
        "PRI",
        "1",
    ],
    [
        184,
        "Qatar",
        "Qatar",
        "Qatar",
        "QA",
        "QAT",
        "974",
    ],
    [
        185,
        "Reino Unido",
        "United Kingdom",
        "Royaume-Uni",
        "GB",
        "GBR",
        "44",
    ],
    [
        186,
        "República Centroafricana",
        "Central African Republic",
        "République Centrafricaine",
        "CF",
        "CAF",
        "236",
    ],
    [
        187,
        "República Checa",
        "Czech Republic",
        "République Tchèque",
        "CZ",
        "CZE",
        "420",
    ],
    [
        188,
        "República Dominicana",
        "Dominican Republic",
        "République Dominicaine",
        "DO",
        "DOM",
        "1 809",
    ],
    [
        189,
        "Reunión",
        "Réunion",
        "Réunion",
        "RE",
        "REU",
        "",
    ],
    [
        190,
        "Ruanda",
        "Rwanda",
        "Rwanda",
        "RW",
        "RWA",
        "250",
    ],
    [
        191,
        "Rumanía",
        "Romania",
        "Roumanie",
        "RO",
        "ROU",
        "40",
    ],
    [
        192,
        "Rusia",
        "Russia",
        "La Russie",
        "RU",
        "RUS",
        "7",
    ],
    [
        193,
        "Sahara Occidental",
        "Western Sahara",
        "Sahara Occidental",
        "EH",
        "ESH",
        "",
    ],
    [
        194,
        "Samoa",
        "Samoa",
        "Samoa",
        "WS",
        "WSM",
        "685",
    ],
    [
        195,
        "Samoa Americana",
        "American Samoa",
        "Les Samoa américaines",
        "AS",
        "ASM",
        "1 684",
    ],
    [
        196,
        "San Bartolomé",
        "Saint Barthélemy",
        "Saint-Barthélemy",
        "BL",
        "BLM",
        "590",
    ],
    [
        197,
        "San Cristóbal y Nieves",
        "Saint Kitts and Nevis",
        "Saint Kitts et Nevis",
        "KN",
        "KNA",
        "1 869",
    ],
    [
        198,
        "San Marino",
        "San Marino",
        "San Marino",
        "SM",
        "SMR",
        "378",
    ],
    [
        199,
        "San Martín (Francia)",
        "Saint Martin (French part)",
        "Saint-Martin (partie française)",
        "MF",
        "MAF",
        "1 599",
    ],
    [
        200,
        "San Pedro y Miquelón",
        "Saint Pierre and Miquelon",
        "Saint-Pierre-et-Miquelon",
        "PM",
        "SPM",
        "508",
    ],
    [
        201,
        "San Vicente y las Granadinas",
        "Saint Vincent and the Grenadines",
        "Saint-Vincent et Grenadines",
        "VC",
        "VCT",
        "1 784",
    ],
    [
        202,
        "Santa Elena",
        "Ascensión y Tristán de Acuña",
        "Ascensión y Tristan de Acuña",
        "SH",
        "SHN",
        "290",
    ],
    [
        203,
        "Santa Lucía",
        "Saint Lucia",
        "Sainte-Lucie",
        "LC",
        "LCA",
        "1 758",
    ],
    [
        204,
        "Santo Tomé y Príncipe",
        "Sao Tome and Principe",
        "Sao Tomé et Principe",
        "ST",
        "STP",
        "239",
    ],
    [
        205,
        "Senegal",
        "Senegal",
        "Sénégal",
        "SN",
        "SEN",
        "221",
    ],
    [
        206,
        "Serbia",
        "Serbia",
        "Serbie",
        "RS",
        "SRB",
        "381",
    ],
    [
        207,
        "Seychelles",
        "Seychelles",
        "Les Seychelles",
        "SC",
        "SYC",
        "248",
    ],
    [
        208,
        "Sierra Leona",
        "Sierra Leone",
        "Sierra Leone",
        "SL",
        "SLE",
        "232",
    ],
    [
        209,
        "Singapur",
        "Singapore",
        "Singapour",
        "SG",
        "SGP",
        "65",
    ],
    [
        210,
        "Siria",
        "Syria",
        "Syrie",
        "SY",
        "SYR",
        "963",
    ],
    [
        211,
        "Somalia",
        "Somalia",
        "Somalie",
        "SO",
        "SOM",
        "252",
    ],
    [
        212,
        "Sri lanka",
        "Sri Lanka",
        "Sri Lanka",
        "LK",
        "LKA",
        "94",
    ],
    [
        213,
        "Sudáfrica",
        "South Africa",
        "Afrique du Sud",
        "ZA",
        "ZAF",
        "27",
    ],
    [
        214,
        "Sudán",
        "Sudan",
        "Soudan",
        "SD",
        "SDN",
        "249",
    ],
    [
        215,
        "Suecia",
        "Sweden",
        "Suède",
        "SE",
        "SWE",
        "46",
    ],
    [
        216,
        "Suiza",
        "Switzerland",
        "Suisse",
        "CH",
        "CHE",
        "41",
    ],
    [
        217,
        "Surinám",
        "Suriname",
        "Surinam",
        "SR",
        "SUR",
        "597",
    ],
    [
        218,
        "Svalbard y Jan Mayen",
        "Svalbard and Jan Mayen",
        "Svalbard et Jan Mayen",
        "SJ",
        "SJM",
        "",
    ],
    [
        219,
        "Swazilandia",
        "Swaziland",
        "Swaziland",
        "SZ",
        "SWZ",
        "268",
    ],
    [
        220,
        "Tadjikistán",
        "Tajikistan",
        "Le Tadjikistan",
        "TJ",
        "TJK",
        "992",
    ],
    [
        221,
        "Tailandia",
        "Thailand",
        "Thaïlande",
        "TH",
        "THA",
        "66",
    ],
    [
        222,
        "Taiwán",
        "Taiwan",
        "Taiwan",
        "TW",
        "TWN",
        "886",
    ],
    [
        223,
        "Tanzania",
        "Tanzania",
        "Tanzanie",
        "TZ",
        "TZA",
        "255",
    ],
    [
        224,
        "Territorio Británico del Océano Índico",
        "British Indian Ocean Territory",
        "Territoire britannique de locéan Indien",
        "IO",
        "IOT",
        "",
    ],
    [
        225,
        "Territorios Australes y Antárticas Franceses",
        "French Southern Territories",
        "Terres australes françaises",
        "TF",
        "ATF",
        "",
    ],
    [
        226,
        "Timor Oriental",
        "East Timor",
        "Timor-Oriental",
        "TL",
        "TLS",
        "670",
    ],
    [
        227,
        "Togo",
        "Togo",
        "Togo",
        "TG",
        "TGO",
        "228",
    ],
    [
        228,
        "Tokelau",
        "Tokelau",
        "Tokélaou",
        "TK",
        "TKL",
        "690",
    ],
    [
        229,
        "Tonga",
        "Tonga",
        "Tonga",
        "TO",
        "TON",
        "676",
    ],
    [
        230,
        "Trinidad y Tobago",
        "Trinidad and Tobago",
        "Trinidad et Tobago",
        "TT",
        "TTO",
        "1 868",
    ],
    [
        231,
        "Tunez",
        "Tunisia",
        "Tunisie",
        "TN",
        "TUN",
        "216",
    ],
    [
        232,
        "Turkmenistán",
        "Turkmenistan",
        "Le Turkménistan",
        "TM",
        "TKM",
        "993",
    ],
    [
        233,
        "Turquía",
        "Turkey",
        "Turquie",
        "TR",
        "TUR",
        "90",
    ],
    [
        234,
        "Tuvalu",
        "Tuvalu",
        "Tuvalu",
        "TV",
        "TUV",
        "688",
    ],
    [
        235,
        "Ucrania",
        "Ukraine",
        "LUkraine",
        "UA",
        "UKR",
        "380",
    ],
    [
        236,
        "Uganda",
        "Uganda",
        "Ouganda",
        "UG",
        "UGA",
        "256",
    ],
    [
        237,
        "Uruguay",
        "Uruguay",
        "Uruguay",
        "UY",
        "URY",
        "598",
    ],
    [
        238,
        "Uzbekistán",
        "Uzbekistan",
        "LOuzbékistan",
        "UZ",
        "UZB",
        "998",
    ],
    [
        239,
        "Vanuatu",
        "Vanuatu",
        "Vanuatu",
        "VU",
        "VUT",
        "678",
    ],
    [
        240,
        "Venezuela",
        "Venezuela",
        "Venezuela",
        "VE",
        "VEN",
        "58",
    ],
    [
        241,
        "Vietnam",
        "Vietnam",
        "Vietnam",
        "VN",
        "VNM",
        "84",
    ],
    [
        242,
        "Wallis y Futuna",
        "Wallis and Futuna",
        "Wallis et Futuna",
        "WF",
        "WLF",
        "681",
    ],
    [
        243,
        "Yemen",
        "Yemen",
        "Yémen",
        "YE",
        "YEM",
        "967",
    ],
    [
        244,
        "Yibuti",
        "Djibouti",
        "Djibouti",
        "DJ",
        "DJI",
        "253",
    ],
    [
        245,
        "Zambia",
        "Zambia",
        "Zambie",
        "ZM",
        "ZMB",
        "260",
    ],
    [
        246,
        "Zimbabue",
        "Zimbabwe",
        "Zimbabwe",
        "ZW",
        "ZWE",
        "263",
    ],
]



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
from django.core.management.base import BaseCommand

from artd_location.data.cities import CITIES
from artd_location.models import City, Region


class Command(BaseCommand):
    help = "Create colombian cities"

    def handle(self, *args, **kwargs):
        for city in CITIES:
            region = Region.objects.get(id=city[4])
            if City.objects.filter(id=city[0]).count() == 0:
                City.objects.create(
                    id=city[0],
                    name=city[3],
                    name_in_capital_letters=city[2],
                    code=city[1],
                    region=region,
                )
                print(f"{city[3]} was created")
            else:
                city_obj = City.objects.get(
                    id=city[0],
                )
                city_obj.name = city[3]
                city_obj.name_in_capital_letters = city[2]
                city_obj.code = city[1]
                city_obj.region = region
                city_obj.save()
                print(f"{city[3]} was updated")



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
from django.contrib import admin

from artd_location.models import City, Country, Region


@admin.register(Country)
class CountryAdmin(admin.ModelAdmin):
    search_fields = [
        "spanish_name",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
    ]
    list_display = [
        "id",
        "spanish_name",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
        "status",
    ]
    readonly_fields = [
        "spanish_name",
        "english_name",
        "nom",
        "iso2",
        "iso3",
        "phone_code",
        "status",
        "created_at",
        "updated_at",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False


@admin.register(Region)
class RegionAdmin(admin.ModelAdmin):
    search_fields = [
        "name",
        "country__spanish_name",
        "country__english_name",
    ]
    list_display = [
        "id",
        "name",
        "country",
        "status",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False


@admin.register(City)
class CityAdmin(admin.ModelAdmin):
    search_fields = [
        "name",
        "name_in_capital_letters",
        "code",
        "region__name",
    ]
    list_display = [
        "name",
        "name_in_capital_letters",
        "region",
        "code",
        "status",
    ]

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request, obj=None):
        return False



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2024
"""
from django.db import models
from django.utils.translation import gettext_lazy as _


class ColombianCitiesBaseModel(models.Model):
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)
    status = models.BooleanField("status", default=True)

    class Meta:
        abstract = True


class Country(ColombianCitiesBaseModel):
    """Model definition for Country."""

    spanish_name = models.CharField(
        _("Country spanish name"),
        help_text=_("Country spanish name"),
        max_length=250,
    )
    english_name = models.CharField(
        _("Country english name"),
        help_text=_("Country english name"),
        max_length=250,
    )
    nom = models.CharField(
        _("Country nom"),
        help_text=_("Country nom"),
        max_length=250,
    )
    iso2 = models.CharField(
        _("Country iso2"),
        help_text=_("Country iso2"),
        max_length=250,
    )
    iso3 = models.CharField(
        _("Country iso3"),
        help_text=_("Country iso3"),
        max_length=250,
    )
    phone_code = models.CharField(
        _("Country phone code"),
        help_text=_("Country phone code"),
        max_length=250,
    )

    @property
    def flag(self):
        return f"https://flagsapi.com/{self.iso2}/flat/64.png"

    class Meta:
        """Meta definition for Country."""

        verbose_name = _("Country")
        verbose_name_plural = _("Countries")

    def __str__(self):
        """Unicode representation of Country."""
        return self.spanish_name


class Region(ColombianCitiesBaseModel):
    """Model definition for Region."""

    name = models.CharField(
        _("Region name"),
        help_text=_("Region name"),
        max_length=100,
    )
    country = models.ForeignKey(
        Country,
        related_name="region_country",
        on_delete=models.CASCADE,
    )

    class Meta:
        """Meta definition for Region."""

        verbose_name = _("Region")
        verbose_name_plural = _("Regions")

    def __str__(self):
        """Unicode representation of Region."""
        return self.name


class City(ColombianCitiesBaseModel):
    """Model definition for City."""

    name = models.CharField(
        _("City name"),
        help_text=_("City name"),
        max_length=100,
    )
    name_in_capital_letters = models.CharField(
        _("Name in capital letters"),
        help_text=_("Name in capital letters"),
        max_length=100,
    )
    code = models.CharField(
        _("City code"),
        help_text=_("City code"),
        max_length=10,
    )
    region = models.ForeignKey(
        Region,
        related_name="city_region",
        on_delete=models.CASCADE,
        help_text=_("Region"),
    )

    @property
    def country_spanish_name(self):
        return self.region.country.spanish_name

    @property
    def country_english_name(self):
        return self.region.country.english_name

    @property
    def region_name(self):
        return self.region.name

    class Meta:
        """Meta definition for City."""

        verbose_name = _("City")
        verbose_name_plural = _("Cities")

    def __str__(self):
        """Unicode representation of City."""
        return self.name



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
REGIONS = [
    [
        1,
        "AMAZONAS",
    ],
    [
        2,
        "ANTIOQUIA",
    ],
    [
        3,
        "ARAUCA",
    ],
    [
        4,
        "ARCHIPIELAGO DE SAN ANDRES",
    ],
    [
        5,
        "ATLÁNTICO",
    ],
    [
        6,
        "BOGOTÁ D.C.",
    ],
    [
        7,
        "BOLIVAR",
    ],
    [
        8,
        "BOYACÁ",
    ],
    [
        9,
        "CALDAS",
    ],
    [
        10,
        "CAQUETA",
    ],
    [
        11,
        "CASANARE",
    ],
    [
        12,
        "CAUCA",
    ],
    [
        13,
        "CESAR",
    ],
    [
        14,
        "CHOCO",
    ],
    [
        15,
        "CORDOBA",
    ],
    [
        16,
        "CUNDINAMARCA",
    ],
    [
        17,
        "GUAINIA",
    ],
    [
        18,
        "GUAVIARE",
    ],
    [
        19,
        "HUILA",
    ],
    [
        20,
        "LA GUAJIRA",
    ],
    [
        21,
        "MAGDALENA",
    ],
    [
        22,
        "META",
    ],
    [
        23,
        "NARIÑO",
    ],
    [
        24,
        "NORTE DE SANTANDER",
    ],
    [
        25,
        "PUTUMAYO",
    ],
    [
        26,
        "QUINDIO",
    ],
    [
        27,
        "RISARALDA",
    ],
    [
        28,
        "SANTANDER",
    ],
    [
        29,
        "SUCRE",
    ],
    [
        30,
        "TOLIMA",
    ],
    [
        31,
        "VALLE DEL CAUCA",
    ],
    [
        32,
        "VAUPES",
    ],
    [
        33,
        "VICHADA",
    ],
]



"""
 * Copyright (C) ArtD SAS - All Rights Reserved
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
"""
from django.core.management.base import BaseCommand

from artd_location.data.regions import REGIONS
from artd_location.models import Country, Region


class Command(BaseCommand):
    help = "Create colombian regions"

    def handle(self, *args, **kwargs):
        country = Country.objects.get(id=45)
        for region in REGIONS:
            if Region.objects.filter(id=region[0]).count() == 0:
                Region.objects.create(
                    id=region[0],
                    name=region[1],
                    country=country,
                )
                print(f"{region[1]} was created")
            else:
                region_obj = Region.objects.get(
                    id=region[0],
                )
                region_obj.name = region[1]
                region_obj.country = country
                region_obj.save()
                print(f"{region[1]} was updated")



# Generated by Django 5.0.1 on 2024-01-28 03:32

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Country",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "spanish_name",
                    models.CharField(
                        help_text="Country spanish name",
                        max_length=250,
                        verbose_name="Country spanish name",
                    ),
                ),
                (
                    "english_name",
                    models.CharField(
                        help_text="Country english name",
                        max_length=250,
                        verbose_name="Country english name",
                    ),
                ),
                (
                    "nom",
                    models.CharField(
                        help_text="Country nom",
                        max_length=250,
                        verbose_name="Country nom",
                    ),
                ),
                (
                    "iso2",
                    models.CharField(
                        help_text="Country iso2",
                        max_length=250,
                        verbose_name="Country iso2",
                    ),
                ),
                (
                    "iso3",
                    models.CharField(
                        help_text="Country iso3",
                        max_length=250,
                        verbose_name="Country iso3",
                    ),
                ),
                (
                    "phone_code",
                    models.CharField(
                        help_text="Country phone code",
                        max_length=250,
                        verbose_name="Country phone code",
                    ),
                ),
            ],
            options={
                "verbose_name": "Country",
                "verbose_name_plural": "Countries",
            },
        ),
        migrations.CreateModel(
            name="Region",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "name",
                    models.CharField(
                        help_text="Region name",
                        max_length=100,
                        verbose_name="Region name",
                    ),
                ),
                (
                    "country",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="region_country",
                        to="artd_location.country",
                    ),
                ),
            ],
            options={
                "verbose_name": "Region",
                "verbose_name_plural": "Regions",
            },
        ),
        migrations.CreateModel(
            name="City",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("status", models.BooleanField(default=True, verbose_name="status")),
                (
                    "name",
                    models.CharField(
                        help_text="City name", max_length=100, verbose_name="City name"
                    ),
                ),
                (
                    "name_in_capital_letters",
                    models.CharField(
                        help_text="Name in capital letters",
                        max_length=100,
                        verbose_name="Name in capital letters",
                    ),
                ),
                (
                    "code",
                    models.CharField(
                        help_text="City code", max_length=10, verbose_name="City code"
                    ),
                ),
                (
                    "region",
                    models.ForeignKey(
                        help_text="Region",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="city_region",
                        to="artd_location.region",
                    ),
                ),
            ],
            options={
                "verbose_name": "City",
                "verbose_name_plural": "Cities",
            },
        ),
    ]
